( cd usr/lib ; rm -rf libssp.so )
( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so )
( cd usr/lib ; rm -rf libmudflap.so.0 )
( cd usr/lib ; ln -sf libmudflap.so.0.0.0 libmudflap.so.0 )
( cd usr/lib ; rm -rf libmudflapth.so.0 )
( cd usr/lib ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so.0 )
( cd usr/lib ; rm -rf libgomp.so )
( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so )
( cd usr/lib ; rm -rf libmudflapth.so )
( cd usr/lib ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so )
( cd usr/lib ; rm -rf libssp.so.0 )
( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so.0 )
( cd usr/lib ; rm -rf libgcc_s.so )
( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/lib ; rm -rf libmudflap.so )
( cd usr/lib ; ln -sf libmudflap.so.0.0.0 libmudflap.so )
( cd usr/lib ; rm -rf libgomp.so.1 )
( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so.1 )
